Documentation
¶
Overview ¶
Package objectstored wraps parsed objects with their storage object IDs.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type StoredBlob ¶
type StoredBlob struct {
// contains filtered or unexported fields
}
StoredBlob is a parsed blob paired with its storage ID.
This Blob object is fully materialized in memory. Consider using objectstore/Store.ReadReaderContent.
func NewStoredBlob ¶
func NewStoredBlob(id objectid.ObjectID, blob *object.Blob) *StoredBlob
NewStoredBlob creates one stored blob wrapper.
func (*StoredBlob) Blob ¶
func (stored *StoredBlob) Blob() *object.Blob
Blob returns the parsed blob value.
func (*StoredBlob) ID ¶
func (stored *StoredBlob) ID() objectid.ObjectID
ID returns the object ID this blob was loaded from.
func (*StoredBlob) Object ¶
func (stored *StoredBlob) Object() object.Object
Object returns the parsed blob as the generic object interface.
type StoredCommit ¶
type StoredCommit struct {
// contains filtered or unexported fields
}
StoredCommit is a parsed commit paired with its storage ID.
func NewStoredCommit ¶
func NewStoredCommit(id objectid.ObjectID, commit *object.Commit) *StoredCommit
NewStoredCommit creates one stored commit wrapper.
func (*StoredCommit) Commit ¶
func (stored *StoredCommit) Commit() *object.Commit
Commit returns the parsed commit value.
func (*StoredCommit) ID ¶
func (stored *StoredCommit) ID() objectid.ObjectID
ID returns the object ID this commit was loaded from.
func (*StoredCommit) Object ¶
func (stored *StoredCommit) Object() object.Object
Object returns the parsed commit as the generic object interface.
type StoredObject ¶
type StoredObject interface {
// ID returns the object ID the object was loaded from.
ID() objectid.ObjectID
// Object returns the parsed object value.
Object() object.Object
}
StoredObject is a parsed object paired with its storage ID.
type StoredTag ¶
type StoredTag struct {
// contains filtered or unexported fields
}
StoredTag is a parsed tag paired with its storage ID.
func NewStoredTag ¶
NewStoredTag creates one stored tag wrapper.
type StoredTree ¶
type StoredTree struct {
// contains filtered or unexported fields
}
StoredTree is a parsed tree paired with its storage ID.
func NewStoredTree ¶
func NewStoredTree(id objectid.ObjectID, tree *object.Tree) *StoredTree
NewStoredTree creates one stored tree wrapper.
func (*StoredTree) ID ¶
func (stored *StoredTree) ID() objectid.ObjectID
ID returns the object ID this tree was loaded from.
func (*StoredTree) Object ¶
func (stored *StoredTree) Object() object.Object
Object returns the parsed tree as the generic object interface.
func (*StoredTree) Tree ¶
func (stored *StoredTree) Tree() *object.Tree
Tree returns the parsed tree value.